Layers
======

Classes
-------

.. currentmodule:: ansys.edb.core.layer

.. autosummary::
   :toctree: _autosummary

   layer.Layer
   stackup_layer.StackupLayer
   via_layer.ViaLayer
   layer_collection.LayerCollection

Enums
-----

.. autosummary::
   :toctree: _autosummary

   layer_collection.LayerType
   layer.TopBottomAssociation
   layer.DrawOverride
   layer.LayerVisibility
   stackup_layer.DCThicknessType
   stackup_layer.RoughnessRegion
   layer_collection.LayerCollectionMode
   layer_collection.LayerTypeSet
   layer_collection.DielectricMergingMethod